==> haskell-input-parsers-0.1.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 input-parsers
version:              0.1.0.1
visibility:           public
id:                   input-parsers-0.1.0.1-LRObxc48Aqz4cJmaKDoWcz
key:                  input-parsers-0.1.0.1-LRObxc48Aqz4cJmaKDoWcz
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  f8f768ab2d7d121aa4fb6aae8d4a1e0f
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/input-parsers-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/input-parsers-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/input-parsers-0.1.0.1
hs-libraries:         HSinput-parsers-0.1.0.1-LRObxc48Aqz4cJmaKDoWcz
depends:
    attoparsec-0.13.2.4-2hXHhVC1QQNJDYHhvxUfCW base-4.14.0.0
    binary-0.8.8.0 bytestring-0.10.10.0
    monoid-subclasses-1.0.1-A3rJeQnXXsy5E5DQPGnAs1 parsec-3.1.14.0
    parsers-0.12.10-7ir65tyrRzzJdzOv4HUHW9 text-1.2.3.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-input-parsers-0.1.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 input-parsers
version:              0.1.0.1
visibility:           public
id:                   input-parsers-0.1.0.1-LVuVeaRk7ZC1vjdIpcz9jV
key:                  input-parsers-0.1.0.1-LVuVeaRk7ZC1vjdIpcz9jV
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  1df571aea7e70a02e17461915ae3c07f
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-8.10.1/site-local/input-parsers-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/input-parsers-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/input-parsers-0.1.0.1
hs-libraries:         HSinput-parsers-0.1.0.1-LVuVeaRk7ZC1vjdIpcz9jV
depends:
    attoparsec-0.13.2.4-KUZn5JNJi8P11hhS9NNN1b base-4.14.0.0
    binary-0.8.8.0 bytestring-0.10.10.0
    monoid-subclasses-1.0.1-Dcx7EHsNh515GuUyYf8DWi parsec-3.1.14.0
    parsers-0.12.10-Dhlz1AIyhfEJiyz9WsWk0O text-1.2.3.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
